summaryrefslogtreecommitdiffstatshomepage
path: root/3rdparty/asio/src/examples/cpp03/services/basic_logger.hpp
diff options
context:
space:
mode:
Diffstat (limited to '3rdparty/asio/src/examples/cpp03/services/basic_logger.hpp')
-rw-r--r--3rdparty/asio/src/examples/cpp03/services/basic_logger.hpp14
1 files changed, 4 insertions, 10 deletions
diff --git a/3rdparty/asio/src/examples/cpp03/services/basic_logger.hpp b/3rdparty/asio/src/examples/cpp03/services/basic_logger.hpp
index 876086a2ecf..b9114d0e6d7 100644
--- a/3rdparty/asio/src/examples/cpp03/services/basic_logger.hpp
+++ b/3rdparty/asio/src/examples/cpp03/services/basic_logger.hpp
@@ -2,7 +2,7 @@
// basic_logger.hpp
// ~~~~~~~~~~~~~~~~
//
-// Copyright (c) 2003-2016 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2021 Christopher M. Kohlhoff (chris at kohlhoff dot com)
//
// Distributed under the Boost Software License, Version 1.0. (See accompanying
// file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -34,13 +34,13 @@ public:
/**
* This constructor creates a logger.
*
* @param io_context The io_context object used to locate the logger service.
*
* @param identifier An identifier for this logger.
*/
- explicit basic_logger(asio::io_context& io_context,
+ explicit basic_logger(asio::execution_context& context,
const std::string& identifier)
- : service_(asio::use_service<Service>(io_context)),
+ : service_(asio::use_service<Service>(context)),
impl_(service_.null())
{
service_.create(impl_, identifier);
@@ -52,12 +52,6 @@ public:
service_.destroy(impl_);
}
- /// Get the io_context associated with the object.
- asio::io_context& get_io_context()
- {
- return service_.get_io_context();
- }
-
/// Set the output file for all logger instances.
void use_file(const std::string& file)
{
@@ -34,13 +34,13 @@ public:
* This constructor creates a logger.
*
- * @param io_context The io_context object used to locate the logger service.
+ * @param context The execution context used to locate the logger service.
*
* @param identifier An identifier for this logger.